Object.defineProperty(exports, "__esModule", {
  value: true
});

var _url = require('url');

var _url2 = _interopRequireDefault(_url);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _string = require('string');

var _string2 = _interopRequireDefault(_string);

var _icon = require('./icon');

var _icon2 = _interopRequireDefault(_icon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

exports['default'] = function (info) {
  return [{
    name: 'garbage/comment',
    filter: ':root',
    replacement: function () {
      function replacement(content, root, $) {
        var removeIfIsComment = function () {
          function removeIfIsComment(node) {
            if (node.type === 'comment') {
              $(node).remove();
            }
          }

          return removeIfIsComment;
        }();

        $('*', root).toArray().forEach(function (node) {
          removeIfIsComment(node);
          node.children.forEach(function (child) {
            removeIfIsComment(child);
          });
        });
      }

      return replacement;
    }()
  }, {
    name: 'font-tag/color',
    filter: 'font[color]',
    replacement: function () {
      function replacement(content, node, $) {
        return '%(' + String($(node).attr('color').toLowerCase()) + ')[' + String(content) + ']';
      }

      return replacement;
    }()
  }, {
    name: 'font-tag/size',
    filter: 'font[size]',
    replacement: function () {
      function replacement(content, node, $) {
        var level = 7 - parseInt($(node).attr('size'), 10);
        level = level === 7 ? 6 : level;
        $(node).replaceWith('<h' + level + '>' + String(content) + '</h' + level + '>');
      }

      return replacement;
    }()
  }, {
    name: 'vbulletin/quote',
    filter: 'div[style]:has(table.voz-bbcode-quote td)',
    replacement: function () {
      function replacement(content, node, $) {
        var $td = $('td', node);
        var firstDiv = $td.children('div')[0];
        if (firstDiv && $(firstDiv).html().trim().startsWith('Originally Posted by ')) {
          // forum post quote
          var $titleDiv = $(firstDiv);
          var author = $titleDiv.children('strong').text();
          var link = $titleDiv.children('a').attr('href');
          // now second div is content-container
          var postContent = $($td.children('div')[1]).html();
          var authorTag = (0, _string2['default'])('Quote ' + String(author)).wrapHTML('b').s;
          var linkTag = (0, _string2['default'])('at %(gray)[' + String(link || 'no link') + ']').wrapHTML('em').s;
          var contentTag = (0, _string2['default'])(postContent).wrapHTML('blockquote').s;

          $(node).replaceWith((0, _string2['default'])(String(authorTag) + ' ' + String(linkTag) + ' ' + String(contentTag)).wrapHTML('p').s);
        } else {
          // free quote
          // now td is content-container
          var _postContent = $td.html();
          $(node).replaceWith((0, _string2['default'])(_postContent).wrapHTML('blockquote').s);
        }
      }

      return replacement;
    }()
  }, {
    name: 'vbulletin/link',
    filter: 'a',
    replacement: function () {
      function replacement(content, node, $) {
        var link = $(node).attr('href');
        var linkObj = _url2['default'].parse(link, true);

        // remove unnecessary 'amp;' in link
        if (link.host === info.host) {
          link = link.replace(/amp;/g, '');
        }

        // remove vBulletin redirect
        if (link.startsWith('/redirect/index.php?link=')) {
          link = unescape(linkObj.query.link);
        }
        $(node).attr('href', link);

        // direct link without alt text
        // TODO: generalize this to all domain
        // if ($(node).html().trim().startsWith('https:\\/\\/vozforums.com')) {
        //   $(node).replaceWith(link);
        // }
      }

      return replacement;
    }()
  }, {
    name: 'vbulletin/icon',
    filter: 'img[src*="/images/smilies/"]',
    replacement: function () {
      function replacement(content, node, $) {
        var filename = _lodash2['default'].last((0, _string2['default'])($(node).attr('src')).chompRight('.gif').s.split('/'));
        return ':' + String(_icon2['default'][filename]) + ':';
      }

      return replacement;
    }()
  }, {
    name: 'invisible/hard-line-break',
    overwrite: 'commonmark/hard-line-break',
    replacement: function () {
      function replacement() {
        return '  \n';
      }

      return replacement;
    }()
  }];
};
//# sourceMappingURL=rules.js.map