function getModule(Settings, Vue, KeenUI, _transform) {
  var ACP = {};

  ACP.init = function () {
    var models = ajaxify.data.models;
    var renderersFromModel = ajaxify.data.renderersFromModel;

    socket.emit('admin.settings.get', {
      hash: 'leech-tool'
    }, function (err, settings) {
      /* eslint no-param-reassign: "off", no-new: "off" */
      // _settings = settings;
      /* vm = */new Vue({
        el: '.leech-tool-settings',
        data: function () {
          function data() {
            var prefix = 'rendererFor-';
            var rendererFor = _transform(settings, function (result, value, key) {
              if (key.startsWith(prefix)) {
                result[key.slice(prefix.length)] = value;
              }
            }, {});
            var currModel = models[0];
            return {
              models: models,
              currModel: currModel,
              rendererFor: rendererFor,
              renderers: renderersFromModel[this.currModel],
              currRenderer: rendererFor[currModel]
            };
          }

          return data;
        }(),

        computed: {
          settings: function () {
            function settings() {
              var _this = this;

              // namespacing rendererFor
              var rendererFor = {};
              Object.keys(this.rendererFor).forEach(function (model) {
                rendererFor['rendererFor-' + String(model)] = _this.rendererFor[model];
              });
              return rendererFor;
            }

            return settings;
          }()
        },
        methods: {
          reloadRenderers: function () {
            function reloadRenderers() {
              this.renderers = renderersFromModel[this.currModel];
              this.currRenderer = this.rendererFor[this.currModel] || this.renderers[0];
            }

            return reloadRenderers;
          }(),
          updateSelectedRenderer: function () {
            function updateSelectedRenderer() {
              this.rendererFor[this.currModel] = this.currRenderer;
            }

            return updateSelectedRenderer;
          }(),
          saveSettings: function () {
            function saveSettings() {
              var _this2 = this;

              socket.emit('admin.settings.set', {
                hash: 'leech-tool',
                values: this.settings
              }, function (saveErr) {
                /* eslint no-underscore-dangle:"off" */
                // Remove unsaved flag to re-enable ajaxify
                app.flags._unsaved = false;

                // Also save to local ajaxify.data
                ajaxify.data.settings = _this2.settings;
                if (saveErr) {
                  app.alert({
                    title: 'Error while saving settings',
                    type: 'error',
                    timeout: 2500
                  });
                } else {
                  app.alert({
                    title: 'Settings Saved',
                    type: 'success',
                    timeout: 2500
                  });
                }
              });
            }

            return saveSettings;
          }()
        },
        created: function () {
          function created() {
            this.reloadRenderers();
          }

          return created;
        }(),

        components: {
          'ui-select': KeenUI.UiSelect
        }
      });
    });
  };

  return ACP;
}

define('admin/plugins/leech-tool', ['settings', 'vue', 'keen-ui', 'lodash/transform'], getModule);
//# sourceMappingURL=admin.js.map